@@ -8,7 +8,6 @@
 var hiddenStuffHeight, mainContentHeight, sidebarHeight, mainContentWidth,
     verticalItemHeight, accordion, resizeTimer, cachedScrollbarWidth;
 
-
 function scrollbarWidth() {
     return cachedScrollbarWidth;
 }
@@ -374,21 +373,29 @@ function setUpAccordion() {
         nextPaneId = pane.attr("data-next-pane-id");
         url = $(this).attr("href");
         $(nextPaneId).html('<div class="loading" />');
-        $.get(url, {}, function (data) {
-            // Update all pane titles and the new pane. Data is the whole
-            // (new) html page.
-            $(".pane").each(function () {
-                // Title of current pane.
-                newTitle = $(data).find("#" + $(this).attr("id")).prev().html();
-                $(this).prev().html(newTitle);
-                // Refresh target pane contents only.
-                ourId = "#" + $(this).attr("id");
-                if (ourId === nextPaneId) {
-                    $(this).html($(data).find(ourId));
-                }
-            });
-            setUpTooltips();
-            setUpTree();
+        $.ajax({
+            type: "GET",
+            url: url,
+            success: function (data) {
+                // Update all pane titles and the new pane. Data is the whole
+                // (new) html page.
+                $(".pane").each(function () {
+                    // Title of current pane.
+                    newTitle = $(data).find("#" + $(this).attr("id")).prev().html();
+                    $(this).prev().html(newTitle);
+                    // Refresh target pane contents only.
+                    ourId = "#" + $(this).attr("id");
+                    if (ourId === nextPaneId) {
+                        $(this).html($(data).find(ourId));
+                    }
+                });
+                setUpTooltips();
+                setUpTree();
+            },
+            error: function (e) {
+                $(nextPaneId).html('<div class="ss_error ss_sprite" />' +
+                                   'Fout bij laden paginaonderdeel.');
+            }
         });
         $("li.selected", pane).removeClass("selected");
         $(this).parent("li").addClass("selected");
@@ -496,6 +503,7 @@ $(window).resize(function () {
 });
 
 $(document).ready(function () {
+
     calculateScrollbarWidth();
     calculateHiddenStuffHeight();
     fillScreen();
@@ -535,6 +543,19 @@ $(document).ready(function () {
         fade: false,
         gravity: 's'
     });
+    $('#transparency-slider').tipsy({
+        delayIn: 200,
+        delayOut: 200,
+        fade: false,
+        gravity: 's'
+    });
+
+
+    // For collapsible tables in popups
+    $('.toggle_button').live('click', function (event) {
+        $('div.pane:visible table').slideDown('fast');
+    });
+
 
     //setUpWorkspaceAcceptableButtons();
     // Light up the selected tab, if available.
